#!/usr/bin/env python3
# -*- coding: utf-8 -*-

"""Test Notifications Endpoint"""

import requests_mock

from acapi2.resources.notificationlist import NotificationList
from acapi2.tests import BaseTest


@requests_mock.Mocker()
class TestNotifications(BaseTest):

    def test_notifications(self, mocker):
        response = {
            '_embedded':
            {'items':
                [{'_embedded':
                    {'author':
                        {'created_at': '2019-11-25T14:07:44+00:00',
                         'email': 'some@email.com',
                         'first_name': 'Name',
                         'last_login_at': '2020-02-07T12:24:29+00:00',
                         'last_name': 'Ue',
                         'picture_url': 'https://accounts.acquia.com/'
                                        'images/users/f0886584-0830-55'
                                        '5d-c234-14ffde052431/'
                                        'style/avatar',
                         'username': 'username',
                         'uuid': 'f0886584-0830-555d-c234-'
                                 '14ffde052431'}},
                    '_links': {
                           'parent': {'href': 'https://cloud.acquia.com/api'
                                              '/notifications'},
                           'self': {
                               'href': 'https://cloud.acquia.com/api/'
                                       'notifications/1bd3487e-71d1-4fca-a2d9'
                                       '-5f969b3d35c1'}},
                  'completed_at': '2020-02-06T13:33:08+00:00',
                  'created_at': '2020-02-06T13:31:48+00:00',
                  'description': 'Log forwarding destination created on Dev.',
                  'event': 'LogForwardingDestinationCreated',
                  'label': 'Log forwarding destination created',
                  'progress': 100,
                  'status': 'completed',
                  'uuid': '1bd3487e-71d1-4fca-a2d9-5f969b3d35c1'}
                 ]},
            '_links': {'filter': {
                'href': 'https://cloud.acquia.com/api/applications/'
                        'f027502b-ed6c-448e-97e8-4a0def7d25e1/'
                        'notifications{?filter}',
                'templated': True},
                'limit': {
                    'href': 'https://cloud.acquia.com/api/'
                            'applications/f027502b-ed6c-448e-97e8-'
                            '4a0def7d25e1/notifications{?limit}',
                    'templated': True},
                'next': {
                    'href': 'https://cloud.acquia.com/api/applications/'
                            'f027502b-ed6c-448e-97e8-4a0def7d25e1/'
                            'notifications?limit=2&offset=2'},
                'offset': {
                    'href': 'https://cloud.acquia.com/api/applications/'
                            'f027502b-ed6c-448e-97e8-4a0def7d25e1/'
                            'notifications{?offset}',
                    'templated': True},
                'parent': {
                    'href': 'https://cloud.acquia.com/api/applications/'
                            'f027502b-ed6c-448e-97e8-4a0def7d25e1?limit=2'},
                'self': {
                    'href': 'https://cloud.acquia.com/api/applications/'
                            'f027502b-ed6c-448e-97e8-4a0def7d25e1/'
                            'notifications?limit=2'},
                'sort': {
                    'href': 'https://cloud.acquia.com/api/applications/'
                            'f027502b-ed6c-448e-97e8-4a0def7d25e1/'
                            'notifications{?sort}',
                    'templated': True}},
            'pagination': {'limit': 2, 'offset': 0, 'total': '81'},
            'total': '81'}

        app_uuid = "f027502b-ed6c-448e-97e8-4a0def7d25e1"
        uri = f"{self.endpoint}/applications/{app_uuid}/notifications"
        mocker.register_uri("GET", uri, status_code=200, json=response)
        notif = self.acquia.application(app_uuid).notifications()

        self.assertIsInstance(notif, NotificationList)



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

"""Agreement list"""

from acapi2.resources.acquialist import AcquiaList
from acapi2.resources.agreement import Agreement
from acapi2.exceptions import AcquiaCloudNoDataException


class AgreementList(AcquiaList):

    def __init__(self, uri: str,
                 api_key: str,
                 api_secret: str,
                 *args, **kwargs) -> None:

        super().__init__(uri, api_key, api_secret, *args, **kwargs)
        self.fetch()

    def fetch(self) -> None:
        agreements = self.request(uri=self.uri).json()
        try:
            agr_items = agreements["_embedded"]["items"]
        except KeyError:
            raise AcquiaCloudNoDataException()
        else:
            for agreement in agr_items:
                agr_uri = agreement["_links"]["self"]["href"]
                self.__setitem__(agreement["uuid"],
                                 Agreement(agr_uri,
                                           self.api_key,
                                           self.api_secret)
                                 )

    @property
    def base_uri(self) -> str:
        return self._base_uri

    @base_uri.setter
    def base_uri(self, base_uri: str):
        self._base_uri = f"{base_uri}/agreements"
